
# 简介
VNodectl 是为了让用户能方便的使用 VNode 对接自建集群和管理 VNode 的命令行工具。
# 安装
通过以下链接进行下载 vnodeclt
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_darwin_amd64.tar.gz
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_darwin_arm64.tar.gz
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_linux_amd64.tar.gz
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_linux_arm64.tar.gz
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_windows_amd64.tar.gz
* https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_windows_arm64.tar.gz

下载
```bash
$ wget https://eci-docs.oss-cn-beijing.aliyuncs.com/vnode/vnodectl_0.0.1-beta_linux_amd64.tar.gz -O vnodectl.tar.gz
```
解压
```bash
$ tar xvf vnodectl.tar.gz
```
拷贝
```bash
$ cp vnodectl /usr/local/bin/vnode
```

# 注意事项
* 以下所有命令都支持 --dry 进行客户端校验。
* 本教程是基于 1.22，1.24 版本 k8s 进行实验，假如在运行过程中遇到 api 版本兼容的错误，请通过 --kubernetes-version 明确指定当前集群版本 。 

# 集群配置
### cluster setup
接入 vnode 需要准备好能访问集群的 kubeconfig，最好具有 admin 权限，该 kubeconfig 仅用于 vnode 在集群中所需要的相关权限以及生成 vnode 注册到集群中所使用的 kubeconfig。目前接入 vnode 有两种方式，普通模式和 tls bootstrap 模式。

__普通模式__
准备前提
* 具有 admin 权限的 kubeconfig，用于配置 vnode 在集群中所需要的权限
* 集群 CA，用于生成 vnode 连接到集群所需要的 kubeconfig（直接使用 admin 权限 kubeconfig 中的 ca，最好是使用启动 apiserver 时传入的 ca，--client-ca-file）
* apiserver 地址
```bash
$ vnode cluster setup --kubeconfig /path/to/kubeconfig --apiserver-address https://1.0.0.0:6443 --cluster-ca-path /path/to/ca.crt
```
__集群版本小于 1.14 的请准确填写当前集群的版本__
```bash
$ vnode cluster setup --kubernetes-version xxx --kubeconfig /path/to/kubeconfig --apiserver-address https://1.0.0.0:6443 --cluster-ca-path /path/to/ca.crt
```

__tls bootstrap 模式__
准备前提
* 具有 admin 权限的 kubeconfig，用于配置 vnode 在集群中所需要的权限
* 集群 CA，用于生成 vnode 连接到集群所需要的 kubeconfig（直接使用 admin 权限 kubeconfig 中的 ca，最好是使用启动 apiserver 时传入的 ca，--client-ca-file）
* apiserver 地址
* 部署 vnode-approver 插件
* tokenSecret（必须为1 6 位）
* tokenId（必须为 6 位）
```bash
$ vnode cluster setup --kubeconfig  /path/to/kubeconfig --bootstrap --bootstrap-token-id eci111 --bootstrap-token-secret eci1233333333333  --apiserver-address https://1.0.0.0:6443 --cluster-ca-path /path/to/ca.crt 
```
部署 vnode-approver 组件
```bash
$ vnode addon enable vnode-approver
```
集群版本小于 1.14 的请准确填写当前集群的版本
```bash
$ vnode cluster setup --kubernetes-version xxx --kubeconfig  /path/to/kubeconfig --bootstrap --bootstrap-token-id eci111 --bootstrap-token-secret eci1233333333333  --apiserver-address https://1.0.0.0:6443 --cluster-ca-path /path/to/ca.crt 
```
### cluster validate
校验集群是否具备接入 vnode 的条件
__普通模式__
```bash
$ vnode cluster validate
```
tls bootstrap 模式
```bash
$ vnode cluster validate --bootstrap
```
### cluster clean
清理集群中 vnode 相关的配置
普通模式
```bash
$ vnode cluster clean --kubeconfig /path/to/kubeconfig
```
tls bootstrap 模式
```bash
$ vnode cluster clean --kubeconfig /path/to/kubeconfig --bootstrap
```
# 功能
### config
vnodectl 运行的时候会读取 ~/.vnode/config 文件，因此需要先配置好该文件
打印 vnode 运行所需的配置信息
```bash
$ vnode config default
```
将配置信息重定向到指定文件，并修改各字段
```bash
$ vnode config default > ~/.vnode/config
```

打印 vnode 当前运行会读取的配置信息
```bash
$ vnode config
```
切换上下文，让 vnode 运行加载其他 context 下的配置
```bash
$ vnode config set-context xxxx
```
### create
需确保  ～/.vnode/config 文件存在且配置正确，执行下列命令创建 vnode。
```bash
$ vnode create
```
### list
需确保  ～/.vnode/config 文件存在且配置正确，执行下列命令查看目前 vnode 的状态
```bash
$ vnode list
```
### describe
需确保  ～/.vnode/config 文件存在且配置正确，执行下列命令查看某一个 vnode 的详细信息
```bash
$ vnode describe vnode-id
```

### update
需确保  ～/.vnode/config 文件存在且配置正确，执行下列命令更新指定的 vnode 配置，目前仅支持更新 vsw。
```bash
$ vnode update vnode-id
```
### delete
需确保  ～/.vnode/config 文件存在且配置正确，执行下列命令删除指定的 vnode，删除前确保 vnode 上不再有 存量的 ECI。
```bash
$ vnode delete vnode-id
```
# 插件
vnode 引入插件机制用于丰富其功能，目前支持的插件有 eci-profile 和 vnode-approver，可通过下列命令查看。其插件的说明都可以在对应 github 仓库地址找到。
```bash
$ vnode addon list --kubeconfig /path/to/kubeconfig
```

### enable
加载插件
``` bash
$ vnode addon enable eci-profile --kubeconfig /path/to/kubeconfig
```
### disable
卸载插件
```bash
$ vnode addon disable eci-profile --kubeconfig /path/to/kubeconfig
```

